################################################
### Imports
################################################
importFrom("DistributionUtils", logHist, safeIntegrate,
           momIntegrated, momChangeAbout,
           skewness, kurtosis, besselRatio, is.wholenumber)
importFrom("GeneralizedHyperbolic",
           dskewlap, hyperbChangePars, ghypChangePars,
           momRecursion,
           gigMom, gigRawMom, gammaRawMom)
importFrom("grDevices", "dev.interactive")
importFrom("graphics", "abline", "curve", "hist", "lines", "par",
           "plot", "title")
importFrom("stats", "integrate", "lm", "na.omit", "nlm", "optim",
           "ppoints", "qqplot", "quantile", "rgamma", "rnorm",
           "splinefun", "uniroot", "var")

################################################
## Functions
################################################
export(skewhypCalcRange)
export(skewhypCheckPars)
export(dskewhyp,pskewhyp,qskewhyp,rskewhyp,ddskewhyp, ppskewhyp,qqskewhyp)
export(skewhypFit)
export(skewhypFitStart)
export(skewhypMean, skewhypVar, skewhypSkew, skewhypKurt, skewhypMode)
export(skewhypMom)
export(skewhypTailPlotLine)

################################################
## S3 classes
################################################
S3method(print, skewhypFit)
S3method(plot, skewhypFit)
S3method(summary, skewhypFit)
S3method(print, summary.skewhypFit)
